# MaterialClassificationProperties

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**material_classification_reference_number** | **str** |  | 
**material_classification_classification** | [**MaterialClassificationClassificationResponse**](MaterialClassificationClassificationResponse.md) |  | 
**material_classification_classification_string** | **str** |  | 
**sample_date** | **datetime** |  | 
**recorded_by_swa_code** | **str** |  | 
**recorded_by_organisation_name** | **str** |  | 
**usrn** | **float** |  | 
**material_type** | [**list[MaterialClassificationMaterialTypeResponse]**](MaterialClassificationMaterialTypeResponse.md) |  | [optional] 
**material_type_string** | **list[str]** |  | [optional] 
**material_classification_centre_point** | [**GeoJSONCentrePoint**](GeoJSONCentrePoint.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

